@@ -385,7 +385,7 @@ Content headers, defaults to a L<Mojo::Headers> object.
   $content = $content->max_buffer_size(1024);
 
 Maximum size in bytes of buffer for content parser, defaults to the value of
-the C<MOJO_MAX_BUFFER_SIZE> environment variable or C<262144> (256KB).
+the C<MOJO_MAX_BUFFER_SIZE> environment variable or C<262144> (256KiB).
 
 =head2 max_leftover_size
 
@@ -394,7 +394,7 @@ the C<MOJO_MAX_BUFFER_SIZE> environment variable or C<262144> (256KB).
 
 Maximum size in bytes of buffer for pipelined HTTP requests, defaults to the
 value of the C<MOJO_MAX_LEFTOVER_SIZE> environment variable or C<262144>
-(256KB).
+(256KiB).
 
 =head2 relaxed
 
