@@ -80,6 +80,10 @@ sub steps {
   my ($self, @steps) = @_;
   $self->{steps} = \@steps;
   $self->ioloop->next_tick($self->begin);
+
+  # DEPRECATED!
+  $self->{deprecated} ||= $self->on(error => sub { });
+
   return $self;
 }
 
@@ -188,7 +192,7 @@ Mojo::IOLoop::Delay - Promises/A+ and flow-control helpers
   # Wrap continuation-passing style APIs with promises
   my $ua = Mojo::UserAgent->new;
   sub get {
-    my $promise = Mojo::IOLoop->delay;
+    my $promise = Mojo::IOLoop::Delay->new;
     $ua->get(@_ => sub {
       my ($ua, $tx) = @_;
       $promise->resolve($tx);
@@ -272,7 +276,7 @@ that leads to the next closure in the series when executed.
 
   use Mojo::IOLoop;
 
-  # Instead of nested closures we now have a simple chain
+  # Instead of nested closures we now have a simple chain of steps
   my $delay = Mojo::IOloop->delay(
     sub {
       my $delay = shift;
@@ -297,32 +301,9 @@ that leads to the next closure in the series when executed.
 
 Another positive side effect of this pattern is that we do not need to call
 L<Mojo::IOLoop/"start"> and L<Mojo::IOLoop/"stop"> manually, because we know
-exactly when our series of closures has reached the end. So L</"wait"> can stop
-the event loop automatically if it had to be started at all in the first place.
-
-=head1 EVENTS
-
-L<Mojo::IOLoop::Delay> inherits all events from L<Mojo::EventEmitter> and can
-emit the following new ones.
-
-=head2 error
-
-  $delay->on(error => sub {
-    my ($delay, $err) = @_;
-    ...
-  });
-
-Emitted if an exception gets thrown in one of the L</"steps">, breaking the
-chain, fatal if unhandled.
-
-=head2 finish
-
-  $delay->on(finish => sub {
-    my ($delay, @args) = @_;
-    ...
-  });
-
-Emitted once the event counter reaches zero and there are no more L</"steps">.
+exactly when our chain of L</"steps"> and/or promises has reached the end. So
+L</"wait"> can stop the event loop automatically if it had to be started at all
+in the first place.
 
 =head1 ATTRIBUTES
 
@@ -337,8 +318,8 @@ Event loop object to control, defaults to the global L<Mojo::IOLoop> singleton.
 
 =head1 METHODS
 
-L<Mojo::IOLoop::Delay> inherits all methods from L<Mojo::EventEmitter> and
-implements the following new ones.
+L<Mojo::IOLoop::Delay> inherits all methods from L<Mojo::Base> and implements
+the following new ones.
 
 =head2 all
 
@@ -410,7 +391,7 @@ it is called, or to its original fulfillment value if the promise is instead
 fulfilled.
 
   # Longer version
-  $delay->then(undef, sub {...});
+  my $new = $delay->then(undef, sub {...});
 
   # Pass along the rejection reason
   $delay->catch(sub {
